sampler sampler0_ : register( s0 );

float _rwd = 1024;
float _rht = 512;

float2 position;
float strength;
float count;

struct PS_INPUT
{
	float4 diffuse	: COLOR0;
	float2 texCoord	: TEXCOORD0;
	float2 vPos	: VPOS;
};

struct PS_OUTPUT
{
	float4 color	: COLOR0;
};

PS_OUTPUT PS( PS_INPUT In ) : COLOR0
{
	PS_OUTPUT Out;

	float offset = (count-floor(count))/count;
	float CurrentTime = count*offset;

	float3 WaveParams = float3(10,0.8,0.1);

	float ratio = _rht/_rwd;

	float2 uv;
		uv.x = In.texCoord.x;
		uv.y = In.texCoord.y;

	float2 pos;
		pos.x = position.x/_rwd;
		pos.y = position.y/_rht;

	float Dist = distance(uv,pos);

	float4 colorTexture = tex2D(sampler0_, uv);
	float4 colorDiffuse = In.diffuse;

	if((Dist <= ((CurrentTime) + (WaveParams.z))) && (Dist >= ((CurrentTime) - (WaveParams.z)))) 
	{
		float Diff = (Dist - CurrentTime); 
		float ScaleDiff = max(0,(1.0 - pow(abs(Diff * WaveParams.x), WaveParams.y))); 
		float DiffTime = Diff  * ScaleDiff;

		float2 DiffTexCoord = normalize(uv - pos);         
        
		uv += ((DiffTexCoord * DiffTime) / (CurrentTime * Dist * strength));

		colorTexture = tex2D(sampler0_, uv);
		colorTexture.r += (colorTexture.r * ScaleDiff) / (0.1 * Dist * 40.0);
		colorTexture.g += (colorTexture.g * ScaleDiff) / (0.1 * Dist * 40.0);
		colorTexture.b += (colorTexture.b * ScaleDiff) / (0.1 * Dist * 40.0);
	}

	float4 color = colorTexture * colorDiffuse;

	color.a = 1;

	Out.color = color;

	return Out;
}

technique Render
{
	pass P0
	{
		PixelShader = compile ps_3_0 PS();
	}
}

